@@ -27,7 +27,7 @@ class AtlantisClient:
             raise InvalidInitParameters('invalid initialization of the required parameters.')
         return self._client_secret
 
-    def issue_token(self, code):
+    def issue_token(self, code, redirect_uri):
         """Realiza a troca do code pelo token
 
         .. deprecated:: 0.0.8
@@ -44,19 +44,22 @@ class AtlantisClient:
 
         :param code: Código concedido pelo Atlantis via redirect (authorization_code)
         :type code: str
+        :param redirect_uri: Endereço de redirecionamento
+        :type redirect_uri: str
         :return: Dicionário com os tokens: ``access_token``, ``id_token`` e ``refresh_token``
         :rtype: dict
         """
-        return requests.post(
+        response = requests.post(
             '{}/api/token'.format(self.atlantis_url),
             data={
                 'code': code,
                 'client_id': self.client_id,
                 'client_secret': self.client_secret,
+                'redirect_uri': self.redirect_uri,
                 'grant_type': 'authorization_code'
             })
-        # response.raise_for_status()
-        # return response.json()
+        response.raise_for_status()
+        return response.json()
 
     def get_public_key(self):
         """Obtém a chave pública do Atlantis para validação do token de acesso
@@ -67,7 +70,7 @@ class AtlantisClient:
         :return: Chave pública
         :rtype: str
         """
-        response = requests.get('{}/api/public-key'.format(self.atlantis_url))
+        response = requests.get('{}/api/jwks'.format(self.atlantis_url))
         response.raise_for_status()
         return response.json()
 
